@@ -301,17 +301,19 @@ class OrionAuthentication(BaseAuthentication):
         except model.DoesNotExist:
             raise exceptions.AuthenticationFailed(_('Invalid token.'))
         try:
-            if token['detail']:
-                return exceptions.AuthenticationFailed(_('Invalid token.'))
+            token_detail = token['detail']
+        except KeyError:
+            token_detail = False
+        if token_detail:
+            raise exceptions.AuthenticationFailed(_('Invalid token.'))
+        try:
+            if not token['user']['is_active']:
+                return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
+            return token['user'], token['Authorization']
         except:
-            try:
-                if not token['user']['is_active']:
-                    return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
-                return token['user'], token['Authorization']
-            except:
-                if not token.user.is_active:
-                    return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
-                return token.user, token.Authorization
+            if not token.user.is_active:
+                return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
+            return token.user, token.Authorization
 
 
 
